# Code Freeze: no PRs accepted temporarily

## PLEASE DO NOT OPEN PULL REQUESTS AGAINST THIS REPO

The Amundsen project is currently transitioning from many sub-repos into a single monorepo.

We are not accepting Pull Requests until Monday, April 26 (at the latest, hopefully earlier). After that time, you'll need to open your PR against the mono-repo.

To read more about this transition, refer to the RFC: https://github.com/amundsen-io/rfcs/blob/master/rfcs/031-monorepo.md

If you have any questions, please find @dorianj on Slack.
